==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/kvirc/kvs/kvi_kvs_treenode_callbackcommand.cpp <==
//=============================================================================
//
//   File : kvi_kvs_treenode_callbackcommand.cpp
//   Created on Thu 09 Oct 2003 02:02:42 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#define __KVIRC__


#include "kvi_kvs_treenode_callbackcommand.h"
#include "kvi_kvs_treenode_datalist.h"
#include "kvi_kvs_script.h"



KviKvsTreeNodeCallbackCommand::KviKvsTreeNodeCallbackCommand(const QChar * pLocation,const QString &szCmdName,KviKvsTreeNodeDataList * params,KviKvsScript * pCallback)
: KviKvsTreeNodeCommandWithParameters(pLocation,szCmdName,params)
{
	m_pCallback = pCallback;
}


KviKvsTreeNodeCallbackCommand::~KviKvsTreeNodeCallbackCommand()
{
	delete m_pCallback;
}


void KviKvsTreeNodeCallbackCommand::dump(const char * prefix)
{
	debug("%s CallbackCommand(%s)",prefix,m_szCmdName.latin1());
	dumpSwitchList(prefix);
	dumpParameterList(prefix);
	dumpCallback(prefix);
}

void KviKvsTreeNodeCallbackCommand::dumpCallback(const char * prefix)
{
	QString tmp = prefix;
	tmp.append("  ");
	m_pCallback->dump(tmp.latin1());
}

==> kvirc_3.4.0.orig.tar.gz: kvirc-3.4.0/src/kvirc/kvs/kvi_kvs_treenode_callbackcommand.cpp <==
//=============================================================================
//
//   File : kvi_kvs_treenode_callbackcommand.cpp
//   Created on Thu 09 Oct 2003 02:02:42 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#define __KVIRC__


#include "kvi_kvs_treenode_callbackcommand.h"
#include "kvi_kvs_treenode_datalist.h"
#include "kvi_kvs_script.h"



KviKvsTreeNodeCallbackCommand::KviKvsTreeNodeCallbackCommand(const QChar * pLocation,const QString &szCmdName,KviKvsTreeNodeDataList * params,KviKvsScript * pCallback)
: KviKvsTreeNodeCommandWithParameters(pLocation,szCmdName,params)
{
#ifdef COMPILE_NEW_KVS
	m_pCallback = pCallback;
#endif
}


KviKvsTreeNodeCallbackCommand::~KviKvsTreeNodeCallbackCommand()
{
#ifdef COMPILE_NEW_KVS
	delete m_pCallback;
#endif
}

void KviKvsTreeNodeCallbackCommand::contextDescription(QString &szBuffer)
{
	KviQString::sprintf(szBuffer,"Callback Command \"%s\"",&m_szCmdName);
}

void KviKvsTreeNodeCallbackCommand::dump(const char * prefix)
{
#ifdef COMPILE_NEW_KVS
	debug("%s CallbackCommand(%s)",prefix,m_szCmdName.utf8().data());
	dumpSwitchList(prefix);
	dumpParameterList(prefix);
	dumpCallback(prefix);
#endif
}

void KviKvsTreeNodeCallbackCommand::dumpCallback(const char * prefix)
{
#ifdef COMPILE_NEW_KVS
	QString tmp = prefix;
	tmp.append("  ");
	m_pCallback->dump(tmp.utf8().data());
#endif
}
